<a id="mypy-boto3-network-firewall"></a>

# mypy-boto3-network-firewall

[![PyPI - mypy-boto3-network-firewall](https://img.shields.io/pypi/v/mypy-boto3-network-firewall.svg?color=blue)](https://pypi.org/project/mypy-boto3-network-firewall)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-network-firewall.svg?color=blue)](https://pypi.org/project/mypy-boto3-network-firewall)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-network-firewall?color=blue)](https://pypistats.org/packages/mypy-boto3-network-firewall)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.NetworkFirewall 1.18.53](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/network-firewall.html#NetworkFirewall)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-network-firewall docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_network_firewall/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-network-firewall](#mypy-boto3-network-firewall)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `NetworkFirewall` service.

```bash
python -m pip install boto3-stubs[network-firewall]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[network-firewall]` in your environment:
  `python -m pip install 'boto3-stubs[network-firewall]'`

Both type checking and auto-complete should work for `NetworkFirewall` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[network-firewall]` in your environment:
  `python -m pip install 'boto3-stubs[network-firewall]'`

Both type checking and auto-complete should work for `NetworkFirewall` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[network-firewall]` in your environment:
  `python -m pip install 'boto3-stubs[network-firewall]'`
- Run `mypy` as usual

Type checking should work for `NetworkFirewall` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[network-firewall]` in your environment:
  `python -m pip install 'boto3-stubs[network-firewall]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `NetworkFirewall` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`NetworkFirewallClient` provides annotations for
`boto3.client("network-firewall")`.

```python
import boto3

from mypy_boto3_network_firewall import NetworkFirewallClient

client: NetworkFirewallClient = boto3.client("network-firewall")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: NetworkFirewallClient = session.client("network-firewall")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_network_firewall.paginator` module contains type annotations for
all paginators.

```python
from mypy_boto3_network_firewall import NetworkFirewallClient
from mypy_boto3_network_firewall.paginator import (
    ListFirewallPoliciesPaginator,
    ListFirewallsPaginator,
    ListRuleGroupsPaginator,
    ListTagsForResourcePaginator,
)

client: NetworkFirewallClient = boto3.client("network-firewall")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_firewall_policies_paginator: ListFirewallPoliciesPaginator = client.get_paginator("list_firewall_policies")
list_firewalls_paginator: ListFirewallsPaginator = client.get_paginator("list_firewalls")
list_rule_groups_paginator: ListRuleGroupsPaginator = client.get_paginator("list_rule_groups")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
```

<a id="literals"></a>

### Literals

`mypy_boto3_network_firewall.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_network_firewall.literals import (
    AttachmentStatusType,
    ConfigurationSyncStateType,
    FirewallStatusValueType,
    GeneratedRulesTypeType,
    ListFirewallPoliciesPaginatorName,
    ListFirewallsPaginatorName,
    ListRuleGroupsPaginatorName,
    ListTagsForResourcePaginatorName,
    LogDestinationTypeType,
    LogTypeType,
    PerObjectSyncStatusType,
    ResourceStatusType,
    RuleGroupTypeType,
    RuleOrderType,
    StatefulActionType,
    StatefulRuleDirectionType,
    StatefulRuleProtocolType,
    TCPFlagType,
    TargetTypeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: AttachmentStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_network_firewall.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_network_firewall.type_defs import (
    ActionDefinitionTypeDef,
    AddressTypeDef,
    AssociateFirewallPolicyRequestRequestTypeDef,
    AssociateFirewallPolicyResponseTypeDef,
    AssociateSubnetsRequestRequestTypeDef,
    AssociateSubnetsResponseTypeDef,
    AttachmentTypeDef,
    CreateFirewallPolicyRequestRequestTypeDef,
    CreateFirewallPolicyResponseTypeDef,
    CreateFirewallRequestRequestTypeDef,
    CreateFirewallResponseTypeDef,
    CreateRuleGroupRequestRequestTypeDef,
    CreateRuleGroupResponseTypeDef,
    CustomActionTypeDef,
    DeleteFirewallPolicyRequestRequestTypeDef,
    DeleteFirewallPolicyResponseTypeDef,
    DeleteFirewallRequestRequestTypeDef,
    DeleteFirewallResponseTypeDef,
    DeleteResourcePolicyRequestRequestTypeDef,
    DeleteRuleGroupRequestRequestTypeDef,
    DeleteRuleGroupResponseTypeDef,
    DescribeFirewallPolicyRequestRequestTypeDef,
    DescribeFirewallPolicyResponseTypeDef,
    DescribeFirewallRequestRequestTypeDef,
    DescribeFirewallResponseTypeDef,
    DescribeLoggingConfigurationRequestRequestTypeDef,
    DescribeLoggingConfigurationResponseTypeDef,
    DescribeResourcePolicyRequestRequestTypeDef,
    DescribeResourcePolicyResponseTypeDef,
    DescribeRuleGroupRequestRequestTypeDef,
    DescribeRuleGroupResponseTypeDef,
    DimensionTypeDef,
    DisassociateSubnetsRequestRequestTypeDef,
    DisassociateSubnetsResponseTypeDef,
    FirewallMetadataTypeDef,
    FirewallPolicyMetadataTypeDef,
    FirewallPolicyResponseTypeDef,
    FirewallPolicyTypeDef,
    FirewallStatusTypeDef,
    FirewallTypeDef,
    HeaderTypeDef,
    IPSetTypeDef,
    ListFirewallPoliciesRequestRequestTypeDef,
    ListFirewallPoliciesResponseTypeDef,
    ListFirewallsRequestRequestTypeDef,
    ListFirewallsResponseTypeDef,
    ListRuleGroupsRequestRequestTypeDef,
    ListRuleGroupsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    LogDestinationConfigTypeDef,
    LoggingConfigurationTypeDef,
    MatchAttributesTypeDef,
    PaginatorConfigTypeDef,
    PerObjectStatusTypeDef,
    PortRangeTypeDef,
    PortSetTypeDef,
    PublishMetricActionTypeDef,
    PutResourcePolicyRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    RuleDefinitionTypeDef,
    RuleGroupMetadataTypeDef,
    RuleGroupResponseTypeDef,
    RuleGroupTypeDef,
    RuleOptionTypeDef,
    RuleVariablesTypeDef,
    RulesSourceListTypeDef,
    RulesSourceTypeDef,
    StatefulEngineOptionsTypeDef,
    StatefulRuleGroupReferenceTypeDef,
    StatefulRuleOptionsTypeDef,
    StatefulRuleTypeDef,
    StatelessRuleGroupReferenceTypeDef,
    StatelessRuleTypeDef,
    StatelessRulesAndCustomActionsTypeDef,
    SubnetMappingTypeDef,
    SyncStateTypeDef,
    TCPFlagFieldTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateFirewallDeleteProtectionRequestRequestTypeDef,
    UpdateFirewallDeleteProtectionResponseTypeDef,
    UpdateFirewallDescriptionRequestRequestTypeDef,
    UpdateFirewallDescriptionResponseTypeDef,
    UpdateFirewallPolicyChangeProtectionRequestRequestTypeDef,
    UpdateFirewallPolicyChangeProtectionResponseTypeDef,
    UpdateFirewallPolicyRequestRequestTypeDef,
    UpdateFirewallPolicyResponseTypeDef,
    UpdateLoggingConfigurationRequestRequestTypeDef,
    UpdateLoggingConfigurationResponseTypeDef,
    UpdateRuleGroupRequestRequestTypeDef,
    UpdateRuleGroupResponseTypeDef,
    UpdateSubnetChangeProtectionRequestRequestTypeDef,
    UpdateSubnetChangeProtectionResponseTypeDef,
)

def get_structure() -> ActionDefinitionTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-network-firewall` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-network-firewall docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_network_firewall/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
